@@ -1,11 +1,12 @@
 import click
-from .commands import new_project
+from .commands import new_project, build_package
 
 @click.group()
 def cli():
     pass
 
 cli.add_command(new_project)
+cli.add_command(build_package)
 
 
 
