@@ -50,7 +50,7 @@ def build_package():
     
     print('Checking folders...')
     if not os.path.exists(SRC_PROJECT_FOLDER):
-        print(f'Fatal: src project folder "{SRC_PROJECT_FOLDER}" not found.')
+        print('Fatal: src project folder "{}" not found.'.format(SRC_PROJECT_FOLDER))
         exit()
     print('SRC project folder OK')
 
@@ -64,11 +64,11 @@ def build_package():
     for route in TOCOPY:
         if os.path.isfile(route):
             os.makedirs(os.path.dirname(os.path.join(BUILD_HERE, route)), exist_ok=True)
-            print(f'Copying file {route}')
+            print('Copying file {}'.format(route))
             shutil.copyfile(os.path.abspath(route), os.path.join(BUILD_HERE, route))
         else:
             os.makedirs(os.path.join(BUILD_HERE, route), exist_ok=True)
-            print(f'Copying tree {route}')
+            print('Copying tree {}'.format(route))
             shutil.rmtree(os.path.join(BUILD_HERE, route))
             shutil.copytree(os.path.abspath(route), os.path.join(BUILD_HERE, route))
 
@@ -81,10 +81,10 @@ def build_package():
             
             os.makedirs(os.path.dirname(dst), exist_ok=True)
             if (file_item.split('.')[-1] != "py"):
-                print(f'Copying {src}')
+                print('Copying {}'.format(src))
                 shutil.copyfile(src, dst)
             else:
-                print(f'Encrypting {file_item}')
+                print('Encrypting {}'.format(file_item))
                 with open(src, 'r', encoding='utf-8') as py:
                     with open(dst.replace('.py', EXT), 'wb+') as mb:
                         mb.write(rc4_encrypt(py.read(), KEY))
