@@ -2,29 +2,31 @@ import os
 import shutil
 
 def ask(text):
-    while (r:=input(text+' [Y/N]: ').lower()) not in ['y','n']:
+    r = ''
+    while r.lower() not in ['y','n']:
+        r = input(text+' [Y/N]: ')
         continue
     
-    return r == 'y'
+    return r.lower() == 'y'
 
 def mkpath(path):
-    print(f'Making path "{path}"')
+    print('Making path "{}"'.format(path))
     try:
         if os.path.exists(path):
-            if ask(f'"{path}" directory found. Overwrite?'):
+            if ask('"{}" directory found. Overwrite?'.format(path)):
                 shutil.rmtree(path)
             else:
                 return False
         os.makedirs(path, exist_ok=True)
         return True
     except OSError as e:
-        print(f'Can`t make path "{path}": {str(e)}')
+        print('Can`t make path "{}": {}'.format(path, str(e)))
         return False
 
 def mkfile(path, content):
-    print(f'Making file "{path}"')
+    print('Making file "{}"'.format(path))
     if os.path.exists(path):
-        if ask(f'"{path}" file found. Overwrite?'):
+        if ask('"{}" file found. Overwrite?'.format(path)):
             os.remove(path)
         else:
             return False
